========
Contents
========

This is a Python package for the quantitative analysis of the interaction of energetic x-rays with matter.
This package is named after one of the discoverers of X-rays, `Wilhelm Roentgen <https://en.wikipedia.org/wiki/Wilhelm_Röntgen>`_.
He was awarded the very first Nobel Prize in Physics "in recognition of the extraordinary services he has rendered by the discovery of the remarkable rays subsequently named after him".
X-rays were originally referred to as Roentgen rays.

.. toctree::
    :maxdepth: 3

    guide/index
    sources
    api
    examples/index
    contributing
    dev-guide/index
    authors
    license
    changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

